import * as i0 from '@angular/core';
import { Input, Component, NgModule } from '@angular/core';
import { NgFor, NgIf } from '@angular/common';

class TextHighlightComponent {
    constructor() {
        this.textToHighlight = '';
    }
    ngOnChanges(changes) {
        this.prepareSubtexts();
    }
    prepareSubtexts() {
        this.subtexts = [];
        if (!this.searchKeywords) {
            this.subtexts = [{
                    text: this.textToHighlight,
                    isMarked: false
                }];
            return;
        }
        const chunks = findAll({
            searchWords: this.searchKeywords,
            textToHighlight: this.textToHighlight,
            autoEscape: true
        });
        chunks.map((chunk) => {
            const { end, highlight, start } = chunk;
            const text = this.textToHighlight.substring(start, end);
            if (highlight) {
                this.subtexts.push({ text, isMarked: true });
            }
            else {
                this.subtexts.push({ text, isMarked: false });
            }
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.6", ngImport: i0, type: TextHighlightComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.6", type: TextHighlightComponent, isStandalone: true, selector: "ng-text-highlight", inputs: { textToHighlight: "textToHighlight", searchKeywords: "searchKeywords" }, usesOnChanges: true, ngImport: i0, template: "<ng-container *ngFor=\"let subtext of subtexts\">\n  <ng-container *ngIf=\"subtext.isMarked\"><mark>{{subtext.text}}</mark></ng-container>\n  <ng-container *ngIf=\"!subtext.isMarked\">{{subtext.text}}</ng-container>\n</ng-container>", dependencies: [{ kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.6", ngImport: i0, type: TextHighlightComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ng-text-highlight', imports: [NgFor, NgIf], standalone: true, template: "<ng-container *ngFor=\"let subtext of subtexts\">\n  <ng-container *ngIf=\"subtext.isMarked\"><mark>{{subtext.text}}</mark></ng-container>\n  <ng-container *ngIf=\"!subtext.isMarked\">{{subtext.text}}</ng-container>\n</ng-container>" }]
        }], propDecorators: { textToHighlight: [{
                type: Input
            }], searchKeywords: [{
                type: Input
            }] } });
const findAll = ({ autoEscape, caseSensitive = false, findChunks = defaultFindChunks, sanitize, searchWords, textToHighlight }) => (fillInChunks({
    chunksToHighlight: combineChunks({
        chunks: findChunks({
            autoEscape,
            caseSensitive,
            sanitize,
            searchWords,
            textToHighlight
        })
    }),
    totalLength: textToHighlight ? textToHighlight.length : 0
}));
const combineChunks = ({ chunks }) => {
    chunks = chunks
        .sort((first, second) => first.start - second.start)
        .reduce((processedChunks, nextChunk) => {
        if (processedChunks.length === 0) {
            return [nextChunk];
        }
        else {
            const prevChunk = processedChunks.pop();
            if (nextChunk.start <= prevChunk.end) {
                const endIndex = Math.max(prevChunk.end, nextChunk.end);
                processedChunks.push({ highlight: false, start: prevChunk.start, end: endIndex });
            }
            else {
                processedChunks.push(prevChunk, nextChunk);
            }
            return processedChunks;
        }
    }, []);
    return chunks;
};
const defaultFindChunks = ({ autoEscape, caseSensitive, sanitize = defaultSanitize, searchWords, textToHighlight }) => {
    textToHighlight = sanitize(textToHighlight);
    return searchWords
        .filter(searchWord => searchWord)
        .reduce((chunks, searchWord) => {
        searchWord = sanitize(searchWord);
        if (autoEscape) {
            searchWord = escapeRegExpFn(searchWord);
        }
        const regex = new RegExp(searchWord, caseSensitive ? 'g' : 'gi');
        let match;
        while ((match = regex.exec(textToHighlight))) {
            let start = match.index;
            let end = regex.lastIndex;
            if (end > start) {
                chunks.push({ highlight: false, start, end });
            }
            if (match.index === regex.lastIndex) {
                regex.lastIndex++;
            }
        }
        return chunks;
    }, []);
};
const fillInChunks = ({ chunksToHighlight, totalLength }) => {
    const allChunks = [];
    const append = (start, end, highlight) => {
        if (end - start > 0) {
            allChunks.push({
                start,
                end,
                highlight
            });
        }
    };
    if (chunksToHighlight.length === 0) {
        append(0, totalLength, false);
    }
    else {
        let lastIndex = 0;
        chunksToHighlight.forEach((chunk) => {
            append(lastIndex, chunk.start, false);
            append(chunk.start, chunk.end, true);
            lastIndex = chunk.end;
        });
        append(lastIndex, totalLength, false);
    }
    return allChunks;
};
function defaultSanitize(string) {
    return string;
}
function escapeRegExpFn(string) {
    return string.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g, '\\$&');
}

class TextHighlightModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.6", ngImport: i0, type: TextHighlightModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.6", ngImport: i0, type: TextHighlightModule, imports: [TextHighlightComponent], exports: [TextHighlightComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.6", ngImport: i0, type: TextHighlightModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.6", ngImport: i0, type: TextHighlightModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [TextHighlightComponent],
                    exports: [TextHighlightComponent],
                }]
        }] });

/*
 * Public API Surface of ng-text-highlight
 */

/**
 * Generated bundle index. Do not edit.
 */

export { TextHighlightComponent, TextHighlightModule };
//# sourceMappingURL=ng-text-highlight.mjs.map
